@@ -179,7 +179,7 @@ class Layer(models.Model):
     minisheet_config = JSONField(default=dict)
 
     main_field = models.ForeignKey(
-        Field, null=True, on_delete=models.CASCADE, related_name="is_main_of"
+        Field, null=True, on_delete=models.SET_NULL, related_name="is_main_of"
     )
 
     interactions = JSONField(default=list)
