@@ -1,5 +1,5 @@
-from .layers import SceneViewset, LayerViewset, LayerView
-from .extras import (
+from .layers import SceneViewset, LayerViewset, LayerView  # NOQA
+from .extras import (  # NOQA
     GeoSourceModelViewset,
     GeostoreLayerViewSet,
     GeostoreFeatureViewSet,
